@@ -6,7 +6,7 @@ import os.path as path
 from revChatGPT.revChatGPT import Chatbot
 
 # Local
-from utilities.printers import prompt_user_for_credentials
+from stackexplain.utilities.printers import prompt_user_for_credentials
 
 CONFIG_FP = path.join(path.expanduser("~"), ".stackexplain.json")
 
